BackendDartLogLevel class abstract

Optional backend capability for backends whose worker isolate keeps its own Dart logger and forwards its records to the main isolate.

Constructors

BackendDartLogLevel()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDartLogLevel(LlamaLogLevel level) → Future<void>
Sets the level the worker's Dart logger forwards from.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited