BackendDecisionCapabilities class

Runtime support for an optional backend decision-model path.

Constructors

BackendDecisionCapabilities({required bool isSupported, String? unsupportedReason})
Creates a backend capability snapshot.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isSupported → bool
Whether decision heads can run on the loaded model.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unsupportedReason → String?
Actionable reason when isSupported is false.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited