BackendDecisionOutput class

Raw head outputs for one sequence.

Constructors

BackendDecisionOutput({required Float32List logits, required Float32List actLogits})
Creates head outputs.
const

Properties

actLogits → Float32List
Action-head logits.
final
hashCode → int
The hash code for this object.
no setterinherited
logits → Float32List
One logit per marker, before temperature scaling.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited