supportsEmbeddings property
bool
get
supportsEmbeddings
Whether embedding calls are expected to be supported by this backend.
Implementation
bool get supportsEmbeddings;
Whether embedding calls are expected to be supported by this backend.
bool get supportsEmbeddings;