penalty property
Whether a GenerationParams.penalty other than its default is applied.
Defaults to false so a backend that predates this field does not
claim it.
Implementation
final bool penalty;
Whether a GenerationParams.penalty other than its default is applied.
Defaults to false so a backend that predates this field does not
claim it.
final bool penalty;