thinkingBudget property

bool thinkingBudget
final

Whether GenerationParams.thinkingBudget is applied.

A runtime that applies it can still reject it for generation with media parts or speculative decoding.

Implementation

final bool thinkingBudget;