BackendGenerationCapabilitiesSupport class abstract

Optional backend capability reporting BackendGenerationCapabilities.

LlamaEngine.backendGenerationCapabilities reports no control as applied for a backend that does not implement this.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generationCapabilities() → Future<BackendGenerationCapabilities>
Reports the controls that the loaded model's runtime applies.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited