BackendGpuEnumeration class abstract

Optional backend capability for enumerating GPU-class devices for offload selection (e.g. pinning to the discrete GPU on a laptop, or surfacing which device is in use).

Constructors

BackendGpuEnumeration()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

listGpuDevices({List<GpuBackend> probeBackends = const []}) → Future<List<GpuDeviceInfo>>
Lists the GPU-class devices the backend exposes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited