BackendModelFileTypeDiagnostics class abstract

Optional backend capability for exposing loaded model file type metadata.

Backends that can identify the loaded model's native file type or quantization format return a ModelFileType. Backends that do not expose this data should omit this capability so high-level APIs return null.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getModelFileType(int modelHandle) → Future<ModelFileType?>
Returns file type metadata for modelHandle, or null when unavailable.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited