supportsStatePersistence property
bool
get
supportsStatePersistence
Whether state save/load calls are expected to be supported by this backend.
Implementation
bool get supportsStatePersistence;
Whether state save/load calls are expected to be supported by this backend.
bool get supportsStatePersistence;