BackendTextToSpeech class abstract

Optional backend capability for dedicated text-to-speech synthesis.

Constructors

BackendTextToSpeech()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelTextToSpeech() → void
Cooperatively cancels the active synthesis, if any.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
synthesizeTextToSpeech(int contextHandle, int mmContextHandle, BackendTextToSpeechRequest request, {void onProgress(BackendTextToSpeechProgress progress)?}) → Future<BackendTextToSpeechResult>
Synthesizes one complete utterance.
textToSpeechCapabilities(int contextHandle, int mmContextHandle) → Future<BackendTextToSpeechCapabilities>
Discovers support for the loaded context and multimodal projector.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited