renderMessageToString method
Renders a message with the active native conversation template.
Implementation
String renderMessageToString(Map<String, dynamic> message) {
throw UnsupportedError('LiteRT-LM runtime requires a native platform.');
}
Renders a message with the active native conversation template.
String renderMessageToString(Map<String, dynamic> message) {
throw UnsupportedError('LiteRT-LM runtime requires a native platform.');
}