DecisionQuestionType enum

Kind of a DecisionQuestion: pick one, rate on a scale, or yes/no.

name is the wire type, and index is Laya's numeric question type.

Inheritance
Available extensions

Values

choice → const DecisionQuestionType

Pick one label from a set of options.

score → const DecisionQuestionType

Rate on ordered levels; the answer is the expected level.

noul → const DecisionQuestionType

Yes or no ("noul", from Jev); the answer is the probability of true.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<DecisionQuestionType>
A constant List of the values in this enum, in order of their declaration.