KvCacheType enum

KV-cache data type for llama_context_params.type_k / type_v. q8_0 ≈ 0.5× the KV memory of f16; q4_0 ≈ 0.25×. Both require flash attention to be enabled (see FlashAttention).

Inheritance
Available extensions

Values

f16 → const KvCacheType

fp16 (default).

q8_0 → const KvCacheType

8-bit quantized.

q4_0 → const KvCacheType

4-bit quantized.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KvCacheType>
A constant List of the values in this enum, in order of their declaration.