BackendDecisionSequence class
Encoder input for one question.
Constructors
- BackendDecisionSequence({required Int32List tokens, required Int32List markers, required DecisionQuestionType questionType})
-
Creates an encoder input.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- markers → Int32List
-
Position in tokens of each option's mask token.
final
- questionType → DecisionQuestionType
-
Type of the question the sequence asks.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokens → Int32List
-
Token ids.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited