BackendGenerationCapabilities class
Optional GenerationParams controls that the loaded model's runtime applies.
Through LlamaEngine, the built-in runtimes reject a non-default value of
a control they report false, except streamBatching, whose thresholds
WebGPU ignores.
Constructors
-
BackendGenerationCapabilities({required bool presencePenalty, required bool minP, required bool thinkingBudget, Set<
SpeculativeDecodingStrategy> speculativeDecodingStrategies = const <SpeculativeDecodingStrategy>{}, bool penalty = false, bool streamBatching = false}) -
Creates a capability snapshot.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minP → bool
-
Whether a non-zero GenerationParams.minP is applied.
final
- penalty → bool
-
Whether a GenerationParams.penalty other than its default is applied.
final
- presencePenalty → bool
-
Whether a non-zero GenerationParams.presencePenalty is applied.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
speculativeDecodingStrategies
→ Set<
SpeculativeDecodingStrategy> -
The strategies that GenerationParams.speculativeDecodingConfig can use.
final
- streamBatching → bool
-
Whether GenerationParams.streamBatchTokenThreshold and
GenerationParams.streamBatchByteThreshold are applied.
final
- thinkingBudget → bool
-
Whether GenerationParams.thinkingBudget is applied.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited