BackendLazyGrammarSupport class abstract
Optional backend capability for reporting lazy grammar activation.
A grammar-capable backend that implements this with false applies
GenerationParams.grammar from the first token and rejects
GenerationParams.grammarLazy. LlamaEngine.create then skips a lazy
template grammar for ToolChoice.auto and parses tool calls best-effort,
and throws LlamaUnsupportedException when a request needs that grammar.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsLazyGrammar → bool
-
Whether GenerationParams.grammarLazy and its triggers are supported.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited