BackendNextTokenScoringSupport class abstract
Optional backend capability for reporting whether BackendNextTokenScoring is actually available for the active runtime.
Delegating backends implement the scoring method whatever they delegate to; this reports what the selected concrete backend supports.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsNextTokenScoring → bool
-
Whether next-token scoring calls are expected to be supported.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited