BackendTextToSpeechProgress class
Progress reported by a backend TTS implementation.
Constructors
- BackendTextToSpeechProgress({required BackendTextToSpeechPhase phase, required int promptTokensRemaining, required int framesGenerated, required bool truncated})
-
Creates a progress snapshot.
const
Properties
- framesGenerated → int
-
Audio-codec frames generated so far.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- phase → BackendTextToSpeechPhase
-
Current synthesis phase.
final
- promptTokensRemaining → int
-
Prompt tokens that have not yet been evaluated.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- truncated → bool
-
Whether generation reached the requested frame limit.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited