BackendTextToSpeechRequest class
Sampling and input values passed to a backend TTS implementation.
Constructors
- BackendTextToSpeechRequest({required String text, String? language, String? speakerAudioPath, Uint8List? speakerAudioBytes, int maxFrames = 512, int promptBatchSize = 512, int topK = 40, double topP = 0.95, double minP = 0.0, double temperature = 0.8, int seed = 0xffffffff})
-
Creates a backend synthesis request.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- language → String?
-
Optional language name or code accepted by the loaded model.
final
- maxFrames → int
-
Maximum number of audio-codec frames to generate.
final
- minP → double
-
Minimum probability sampling cutoff.
final
- promptBatchSize → int
-
Prompt evaluation batch size.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seed → int
-
Random seed.
final
- speakerAudioBytes → Uint8List?
-
Optional encoded reference-audio bytes.
final
- speakerAudioPath → String?
-
Optional local encoded reference-audio path.
final
- temperature → double
-
Sampling temperature.
final
- text → String
-
Text to synthesize.
final
- topK → int
-
Top-k sampling cutoff.
final
- topP → double
-
Top-p sampling cutoff.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited