BackendTextToSpeechResult class
Complete PCM output returned by a backend TTS implementation.
Constructors
- BackendTextToSpeechResult({required Float32List samples, required int sampleRateHz, required int channelCount, required int framesGenerated, required bool truncated})
-
Creates a backend synthesis result.
const
Properties
- channelCount → int
-
Number of interleaved output channels.
final
- framesGenerated → int
-
Number of audio-codec frames generated.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRateHz → int
-
Output sample rate in Hertz.
final
- samples → Float32List
-
Interleaved normalized float32 PCM samples.
final
- truncated → bool
-
Whether generation reached the requested frame limit.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited